@@ -9,21 +9,27 @@ connectors = {
   'googleAnalytics' : googleAnalytics
 }
 
+required = ['params','db','q','name']
+
+
 class BaseQuery(object):
 
   desc=''
   params=[]
   use_headers = False
 
+
   def __str__(self):
     return self.name
 
   def __init__(self, **kwargs):
+    print kwargs
     self.connector = connectors['postgres']()
     if kwargs['db'] in dbs.keys():
       self.connector = connectors[dbs[kwargs['db']]['type']]()
 
-    for k in kwargs.keys():
+    for k in required:
+      print k
       self.__setattr__(k, kwargs[k])
       self.connector.__setattr__(k, kwargs[k])
 
